@@ -421,19 +421,20 @@ static GtUword gt_mmsearch_extendright(const GtEncseq *dbencseq,
 }
 
 void gt_queryuniquematch(bool selfmatch,
-                        const Suffixarray *suffixarray,
-                        uint64_t queryunitnum,
-                        GtQueryrepresentation *queryrep,
-                        GtUword minmatchlength,
-                        GtProcessquerymatch processquerymatch,
-                        void *processquerymatchinfo,
-                        GtQuerymatch *querymatchspaceptr)
+                         const Suffixarray *suffixarray,
+                         uint64_t queryunitnum,
+                         GtQueryrepresentation *queryrep,
+                         GtUword minmatchlength,
+                         GtProcessquerymatch processquerymatch,
+                         void *processquerymatchinfo,
+                         GtQuerymatch *querymatchspaceptr)
 {
   GtUword offset, totallength = gt_encseq_total_length(suffixarray->encseq),
           localqueryoffset = 0;
   uint64_t localqueryunitnum = queryunitnum;
 
   gt_assert(!selfmatch && queryrep->seqlen >= minmatchlength);
+  /*XXX gt_assert(!gt_querymatch_seq_desc_display(querymatchspaceptr));*/
   for (offset = 0; offset <= queryrep->seqlen - minmatchlength; offset++)
   {
     GtUword matchlen, dbstart;
@@ -454,23 +455,26 @@ void gt_queryuniquematch(bool selfmatch,
                              queryrep->sequence))
     {
       GtUword dbseqnum = gt_encseq_seqnum(suffixarray->encseq,dbstart),
-              dbseqstartpos = gt_encseq_seqstartpos(suffixarray->encseq,
-                                                    dbseqnum),
-              dbseqlen = gt_encseq_seqlength(suffixarray->encseq,dbseqnum);
+              dbseqlen = gt_encseq_seqlength(suffixarray->encseq,dbseqnum),
+              db_seqstart = gt_encseq_seqstartpos(suffixarray->encseq,dbseqnum);
 
       gt_querymatch_init(querymatchspaceptr,
                          matchlen,
-                         dbstart,
                          dbseqnum,
-                         dbstart - dbseqstartpos,
+                         dbstart - db_seqstart,
+                         db_seqstart,
                          dbseqlen,
                          0, /* score */
                          0, /* edist */
+                         0, /* mismatches */
                          selfmatch,
                          localqueryunitnum,
                          matchlen,
                          localqueryoffset,
-                         queryrep->seqlen);
+                         0,
+                         queryrep->seqlen,
+                         NULL,
+                         NULL);
       processquerymatch(processquerymatchinfo,querymatchspaceptr);
     }
     if (queryrep->sequence[offset] == (GtUchar) SEPARATOR)
@@ -525,7 +529,8 @@ static void gt_querysubstringmatch(bool selfmatch,
                                     dbstart,
                                     &querysubstring))
       {
-        GtUword dbseqnum, dbseqstartpos, dbseqlen, extend;
+        GtUword dbseqnum, dbseqlen, db_seqstart, extend;
+        const char *db_desc = NULL, *query_desc = NULL;
 
         extend = gt_mmsearch_extendright(dbencseq,
                                          mmsi->esr,
@@ -538,25 +543,29 @@ static void gt_querysubstringmatch(bool selfmatch,
         if (gt_encseq_has_multiseq_support(dbencseq))
         {
           dbseqnum = gt_encseq_seqnum(dbencseq,dbstart);
-          dbseqstartpos = gt_encseq_seqstartpos(dbencseq,dbseqnum);
           dbseqlen = gt_encseq_seqlength(dbencseq,dbseqnum);
+          db_seqstart = gt_encseq_seqstartpos(dbencseq,dbseqnum);
         } else
         {
-          dbseqnum = dbseqstartpos = dbseqlen = 0;
+          dbseqnum = dbseqlen = db_seqstart = 0;
         }
         gt_querymatch_init(querymatchspaceptr,
                            minmatchlength + extend,
-                           dbstart,
                            dbseqnum,
-                           dbstart - dbseqstartpos,
+                           dbstart - db_seqstart,
+                           db_seqstart,
                            dbseqlen,
                            0, /* score */
                            0, /* edist */
+                           0, /* mismatches */
                            selfmatch,
                            localqueryunitnum,
                            minmatchlength + extend,
                            localqueryoffset,
-                           queryrep->seqlen);
+                           0,
+                           queryrep->seqlen,
+                           db_desc,
+                           query_desc);
         processquerymatch(processquerymatchinfo,querymatchspaceptr);
       }
     }
@@ -829,6 +838,13 @@ const GtUchar *gt_querysubstringmatchiterator_query(
   return qsmi->query_for_seqit;
 }
 
+const char *gt_querysubstringmatchiterator_desc(
+                      const GtQuerysubstringmatchiterator *qsmi)
+{
+  gt_assert(qsmi != NULL && qsmi->desc != NULL);
+  return qsmi->desc;
+}
+
 int gt_querysubstringmatchiterator_next(GtQuerysubstringmatchiterator *qsmi,
                                         GtError *err)
 {
